==> qubit-cli-1.33.1.tgz: package/README.md <==
 # ![extension icon](./chrome-extension/icons/on48.png)
## Qubit-CLI

A client to facilitate local development of experiences for the qubit platform

## Features

fast previewing
- built in experience server for instant preview on any website
- live hot reloading of css
- ability to enable live hot reloading of js with a little bit of code

local tools
- use your local editor/IDE of choice to write experience code
- use your own workflow and versioning tools
- write and run local unit tests

interact with the platform from the command line
- create new experiences or clone existing ones
- push remote changes to the platform
- pull remote changes from the platform
- publish | pause | resume your experience

templates
- speed up local development
- share ideas and examples

## Installation

```
using npm:
npm install -g qubitdigital/qubit-cli

using yarn:
yarn global add qubitdigital/qubit-cli

qubit login
```

## Setup

```
qubit extension
```
then drag the chrome-extension folder into the chrome extensions pane

## Tutorials
- [getting-started](docs/tutorials/getting-started.md)
- [hot-reloading](docs/tutorials/hot-reloading.md)
- [pushing-and-pulling](docs/tutorials/pushing-and-pulling.md)
- [templates](docs/tutorials/templates.md)
- [manipulating-experiences](docs/tutorials/manipulating-experiences.md)
- [links](docs/tutorials/links.md)
- [tips-and-tricks](docs/tutorials/tips-and-tricks.md)

[![js-standard-style](https://img.shields.io/badge/code%20style-standard-brightgreen.svg)](http://standardjs.com/)

==> qubit-cli-1.33.3.tgz: package/README.md <==
 # ![logo](https://user-images.githubusercontent.com/640611/32888373-fbdc7134-cabe-11e7-9b0e-027a49cef8bf.png)
## Qubit-CLI

A client to facilitate local development of experiences for the qubit platform

## Features

fast previewing
- built in experience server for instant preview on any website
- live hot reloading of css
- ability to enable live hot reloading of js with a little bit of code

local tools
- use your local editor/IDE of choice to write experience code
- use your own workflow and versioning tools
- write and run local unit tests

interact with the platform from the command line
- create new experiences or clone existing ones
- push remote changes to the platform
- pull remote changes from the platform
- publish | pause | resume your experience

templates
- speed up local development
- share ideas and examples

## Installation

```
using npm:
npm install -g qubit-cli

using yarn:
yarn global add qubit-cli

qubit login
```

## Setup

```
qubit extension
```
then drag the chrome-extension folder into the chrome extensions pane

## Tutorials
- [getting-started](docs/tutorials/getting-started.md)
- [hot-reloading](docs/tutorials/hot-reloading.md)
- [pushing-and-pulling](docs/tutorials/pushing-and-pulling.md)
- [templates](docs/tutorials/templates.md)
- [manipulating-experiences](docs/tutorials/manipulating-experiences.md)
- [links](docs/tutorials/links.md)
- [tips-and-tricks](docs/tutorials/tips-and-tricks.md)

[![js-standard-style](https://img.shields.io/badge/code%20style-standard-brightgreen.svg)](http://standardjs.com/)
